﻿import es
import gamethread
import keyvalues
import langlib
import os
import playerlib
import popuplib

lang_msg = es.import_addon("soccer_mod_2011")

lang_dir = "cstrike/addons/eventscripts/soccer_mod_2011/language/"

messages_text = langlib.Strings(lang_dir + "admin/manager/messages_manager_maps.ini")
popup_common = langlib.Strings(lang_dir + "popup_common.ini")
popup_text = langlib.Strings(lang_dir + "admin/manager/popup_manager_maps.ini")

# ******************** Load ********************
def load():
	if os.path.isfile("cstrike/cfg/soccer_mod/es_soccer_mod_maps_db.txt") == True:
		es.keygroupload("soccer_mod_maps", "soccer_mod")
	else:
		es.keygroupcreate("soccer_mod_maps")
		es.keycreate("soccer_mod_maps", "ka_soccer_xsl_stadium_b1")
		es.keysetvalue("soccer_mod_maps", "ka_soccer_xsl_stadium_b1", "soccer_mod", 1)
		es.keygroupsave("soccer_mod_maps", "soccer_mod")

	create_popup()

	es.addons.registerSayFilter(filter)

# ******************** Create popup ********************
def create_popup():
	popup = popuplib.create("sm_popup_admin_manager_maps")

	popup.addline("SOCCER MOD %s" % (popup_text("title")))
	popup.addline(" ")
	popup.addline("->1. %s" % (popup_text("add")))
	popup.addline("->2. %s" % (popup_text("add_map")))
	popup.addline("->3. %s" % (popup_text("remove")))
	popup.addline(" ")
	popup.addline("->9. %s" % (popup_common("back")))
	popup.addline(" ")
	popup.addline("0. %s" % (popup_common("close")))

	popup.select(1, select_add_map)
	popup.select(2, select_add_map_server)
	popup.select(3, select_remove_map)

	for i in range(4, 9):
		popup.submenu(i, "sm_popup_admin_manager_maps")

	popup.submenu(9, "sm_popup_admin_manager")

# ******************** Say filter ********************
def filter(userid, text, teamonly):
	steamid = es.getplayersteamid(userid)

	if es.exists("key", "sm_keygroup_set", steamid) == 1:
		type = es.keygetvalue("sm_keygroup_set", steamid, "setting_type")
		text = text.strip('"')

		if type == "manager_map_add":
			add_map(text, userid)
			return (0, None, 0)
		else:
			return (userid, text, teamonly)
	else:
		return (userid, text, teamonly)

# ******************** Popup choice ********************
def select_add_map(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	if es.exists("key", "sm_keygroup_set", player.steamid) == 0:
		es.keycreate("sm_keygroup_set", player.steamid)

	es.keysetvalue("sm_keygroup_set", player.steamid, "setting_type", "manager_map_add")

	es.tell(userid, "#green", messages_text("add_map", tokens, player.get("lang")))

def select_add_map_server(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	myPopup = popuplib.easymenu(name, None, add_map_server)
	myPopup.settitle("Select a map")

	dir = "cstrike/maps"
	list = os.listdir(dir)
	list.sort()
	for item in list:
		if os.path.isdir(dir + "/" + item) == False:
			type = item.split(".")
			length = len(type) - 1
			if type[length] == "bsp":
				map = item[0:len(item) - 4]
				if es.exists("key", "soccer_mod_maps", map) == 0:
					myPopup.addoption(map, map)

	myPopup.submenu(10, "sm_popup_admin_manager_maps")

	popuplib.send(name, userid)

def select_remove_map(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	myPopup = popuplib.easymenu(name, None, remove_map)
	myPopup.settitle(messages_text("remove_map"))

	maps = keyvalues.getKeyGroup("soccer_mod_maps")
	for item in maps:
		myPopup.addoption(item, item)

	myPopup.submenu(10, "sm_popup_admin_manager_maps")

	popuplib.send(name, userid)

# ******************** Easymenu choice ********************
def remove_map(userid, choice, keymenuname):
	tokens = {}
	tokens["name"] = str(choice).encode("utf-8")
	player = playerlib.getPlayer(userid)

	number = 0
	for map in keyvalues.getKeyGroup("soccer_mod_maps"):
		number += 1

	if number > 1:
		if es.exists("key", "soccer_mod_maps", choice) == 1:
			es.keydelete("soccer_mod_maps", choice)
			es.keygroupsave("soccer_mod_maps", "soccer_mod")

			es.tell(userid, "#green", messages_text("map_removed", tokens, player.get("lang")))
		else:
			es.tell(userid, "#green", messages_text("remove_map_no_exist", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages_text("1_map", tokens, player.get("lang")))

	popuplib.send("sm_popup_admin_manager_maps", userid)

def add_map_server(userid, choice, keymenuname):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	add_map(choice, userid)

# ******************** Functions ********************
def add_map(text, userid):
	player = playerlib.getPlayer(userid)

	if text != "!cancel":
		tokens = {}
		tokens["name"] = text

		if es.exists("key", "soccer_mod_maps", text) == 0:
			if es.exists("map", text) == 1:
				es.keycreate("soccer_mod_maps", text)
				es.keysetvalue("soccer_mod_maps", text, "soccer_mod", 1)

				es.server.cmd("keygroupsort soccer_mod_maps soccer_mod_maps asc #alpha")
				es.keygroupsave("soccer_mod_maps", "soccer_mod")

				es.tell(userid, "#green", messages_text("map_added", tokens, player.get("lang")))

				if es.ServerVar("eventscripts_currentmap") == text:
					if es.ServerVar("soccer_mod_allowed") == 0:
						lang_msg.tell(messages_text, "map_restart", tokens)

						gamethread.delayed(3, es.server.queuecmd, ("changelevel %s" % (text)))
			else:
				es.tell(userid, "#green", messages_text("map_no_exist", tokens, player.get("lang")))
		else:
			es.tell(userid, "#green", messages_text("map_exist", tokens, player.get("lang")))

	if es.exists("key", "sm_keygroup_set", player.steamid) == 1:
		es.keydelete("sm_keygroup_set", player.steamid)

	popuplib.send("sm_popup_admin_manager_maps", userid)

# ******************** Unload ********************
def unload():
	es.keygroupdelete("soccer_mod_maps")

	popuplib.delete("sm_popup_admin_manager_maps")

	es.addons.unregisterSayFilter(filter)